==> eslint-plugin-migrate-to-typescript-1.0.2.tgz: package/README.md <==
# eslint-plugin-migrate-to-typescript

<p align="center" style="text-align: center;">
A compact plugin that aims to help you migrate existing javascript projects to typescript easily, with minimum effort, and minimum mistakes. Focusing on the main differences of javascript's module systems and typescript's ESM syntax (CommonJS and ESM).

</p>

<p align="center">
<img src="https://github.com/uniqorg/eslint-extensions/blob/main/assets/eslint-logo.svg" alt="Logo" width="450"></p>
</p>

<p align="center">
This project is part of the [uniqorg/eslint-extensions](https://github.com/uniqorg/eslint-extensions) repo that includes different conventions we spread through [ESLint](https://eslint.org/).
</p>

<p align="center">
  <a href="https://app.circleci.com/pipelines/github/uniqorg/eslint-plugin-migrate-to-typescript?branch=main" target="_blank">
    <img src="https://img.shields.io/circleci/build/github/uniqorg/eslint-plugin-migrate-to-typescript/main" alt="CircleCI" />
  </a>
  <a href="https://www.npmjs.com/package/eslint-plugin-migrate-to-typescript" target="_blank">
    <img src="https://img.shields.io/npm/dm/eslint-plugin-migrate-to-typescript" alt="npm downloads" />
  </a>
  <a href="https://codecov.io/gh/uniqorg/eslint-extensions">
    <img src="https://codecov.io/gh/uniqorg/eslint-extensions/branch/main/graph/badge.svg?token=R2J9M4Q2RA" alt="codecov" />
  </a>
</p>

<p align="center">
  View our
  <a href="https://uniqorg.github.io/eslint-extensions">
    documentation
  </a>
  to get started.
</p>

==> eslint-plugin-migrate-to-typescript-1.0.3.tgz: package/README.md <==
# eslint-plugin-migrate-to-typescript

<p align="center" style="text-align: center;">
A compact plugin that aims to help you migrate existing javascript projects to typescript easily, with minimum effort, and minimum mistakes. Focusing on the main differences of javascript's module systems and typescript's ESM syntax (CommonJS and ESM).

</p>

<p align="center">
<img src="https://github.com/uniqorg/eslint-extensions/blob/main/assets/eslint-logo.svg" alt="Logo" width="450"></p>
</p>

<p align="center">

This project is part of the
<a href="https://github.com/uniqorg/eslint-extensions">
uniqorg/eslint-extensions
</a> repo that includes different conventions we spread through [ESLint](https://eslint.org/).

</p>

<p align="center">
  <a href="https://app.circleci.com/pipelines/github/uniqorg/eslint-plugin-migrate-to-typescript?branch=main" target="_blank">
    <img src="https://img.shields.io/circleci/build/github/uniqorg/eslint-plugin-migrate-to-typescript/main" alt="CircleCI" />
  </a>
  <a href="https://www.npmjs.com/package/eslint-plugin-migrate-to-typescript" target="_blank">
    <img src="https://img.shields.io/npm/dm/eslint-plugin-migrate-to-typescript" alt="npm downloads" />
  </a>
  <a href="https://codecov.io/gh/uniqorg/eslint-extensions">
    <img src="https://codecov.io/gh/uniqorg/eslint-extensions/branch/main/graph/badge.svg?token=R2J9M4Q2RA" alt="codecov" />
  </a>
</p>

<p align="center">
  View our
  <a href="https://uniqorg.github.io/eslint-extensions">
    documentation
  </a>
  to get started.
</p>
